/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * Copyright © 2014-2016 Michael Catanzaro
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 2 of the License, or (at your option) any later
 * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
 * license.
 */

#ifndef GNOME_CHESS_PORTABILITY_H
#define GNOME_CHESS_PORTABILITY_H

void maybe_kill_orphan_engine ();

#endif /* GNOME_CHESS_PORTABILITY_H */
